@@ -9,12 +9,10 @@
 #'
 #' @param ... Other named arguments, passed to \code{\link{compute_mallows}}.
 #'
-#' @return A list of Mallows model, one for each number of mixtures that
+#' @return A list of Mallows models of class \code{BayesMallowsMixtures}, with one element
+#' for each number of mixtures that
 #' was computed. This object can be studied with \code{\link{plot_elbow}}.
 #'
-#' @details \code{compute_mallows_mixtures} always sets \code{include_wcd = TRUE}
-#' in the code to \code{\link{compute_mallows}}, since the purpose of this
-#' function is to create an elbow plot with \code{\link{plot_elbow}}.
 #'
 #' @export
 #'
@@ -25,6 +23,9 @@ compute_mallows_mixtures <- function(n_clusters, ...){
 
   models <- purrr::map(n_clusters, function(x) {
     message(paste0("Computing Mallows model with ", x, " clusters."))
-    compute_mallows(..., n_clusters = x, include_wcd = TRUE)
+    compute_mallows(..., n_clusters = x)
   })
+
+  class(models) <- "BayesMallowsMixtures"
+  return(models)
 }
